@@ -34,17 +34,17 @@ public:
 protected:
 	FileRecordMergeMgr *_frm;
 	Bed3Interval _outRecord;
-	QuickString _currChrom;
+	string _currChrom;
 	const NewGenomeFile *_genomeFile;
 	int _currStartPos;
 	RecordOutputMgr *_outputMgr;
-	const vector<QuickString> &_chromList;
+	const vector<string> &_chromList;
 	int _currPosInGenomeList;
 
 	virtual ContextComplement *upCast(ContextBase *context) { return static_cast<ContextComplement *>(context); }
 
 	void outPutLastRecordInPrevChrom();
-	bool fastForward(const QuickString &newChrom);
+	bool fastForward(const string &newChrom);
 	void printRecord(int endPos);
 
 };
