@@ -22,13 +22,13 @@ public:
 	void setNumFixedFields(int numFields);
 	virtual bool initFromFile(SingleLineDelimTextFileReader *);
 	virtual void clear();
-	virtual void print(QuickString &outBuf) const;
-	virtual void print(QuickString &outBuf, int start, int end) const;
-	virtual void print(QuickString &outBuf, const QuickString & start, const QuickString & end) const;
-	virtual void printNull(QuickString &outBuf) const;
+	virtual void print(string &outBuf) const;
+	virtual void print(string &outBuf, int start, int end) const;
+	virtual void print(string &outBuf, const string & start, const string & end) const;
+	virtual void printNull(string &outBuf) const;
 	virtual FileRecordTypeChecker::RECORD_TYPE getType() const { return FileRecordTypeChecker::BED_PLUS_RECORD_TYPE; }
 
-	virtual const QuickString &getField(int fieldNum) const;
+	virtual const string &getField(int fieldNum) const;
 	virtual int getNumFields() const  { return _numFixedFields + _plusFields.size(); }
 
 	virtual void setNumPrintFields(int num) { _numPrintFields = num; }
@@ -42,8 +42,8 @@ protected:
 	PlusFields _plusFields;
 	int _numPrintFields;
 
-	void printBed6PlusFields(QuickString &outBuf) const;
-	void printBed6PlusNullFields(QuickString &outBuf) const;
+	void printBed6PlusFields(string &outBuf) const;
+	void printBed6PlusNullFields(string &outBuf) const;
 
 };
 
