@@ -19,22 +19,22 @@ public:
 	VcfRecord() {}
 	virtual bool initFromFile(SingleLineDelimTextFileReader *);
 	virtual void clear();
-	void print(QuickString &outBuf) const;
-	void print(QuickString &outBuf, int start, int end) const;
-	void print(QuickString &outBuf, const QuickString & start, const QuickString & end) const;
-	virtual void printNull(QuickString &outBuf) const;
+	void print(string &outBuf) const;
+	void print(string &outBuf, int start, int end) const;
+	void print(string &outBuf, const string & start, const string & end) const;
+	virtual void printNull(string &outBuf) const;
 	virtual FileRecordTypeChecker::RECORD_TYPE getType() const { return FileRecordTypeChecker::VCF_RECORD_TYPE; }
 
-	virtual const QuickString &getField(int fieldNum) const;
+	virtual const string &getField(int fieldNum) const;
 	static bool isNumericField(int fieldNum);
 
 	virtual bool isZeroBased() const {return false;};
 protected:
-	QuickString _varRef;
-	QuickString _varAlt;
+	string _varRef;
+	string _varAlt;
 	static const int numFixedFields = 6;
 
-	void printOtherFields(QuickString &outBuf) const;
+	void printOtherFields(string &outBuf) const;
 };
 
 #endif /* VCFRECORD_H_ */
