@@ -84,12 +84,6 @@ bool RecordOutputMgr::printKeyAndTerminate(RecordKeyVector &keyList) {
 		//bed3 format, which is surprisingly difficult to do. Had to use the following:
 		const Bed3Interval *bed3 = static_cast<const Bed3Interval *>(keyList.getKey());
 		bed3->Bed3Interval::print(_outBuf);
-
-		//in addition, if we're doing stranded merges, we need to print the strand sign.
-		if (_context->getDesiredStrand() != FileRecordMergeMgr::ANY_STRAND) {
-			_outBuf.append("\t");
-			_outBuf.append(keyList.getKey()->getStrand());
-		}
 		return false;
 	}
 	printBamType bamCode = printBamRecord(keyList);
@@ -125,13 +119,13 @@ RecordOutputMgr::printBamType RecordOutputMgr::printBamRecord(RecordKeyVector &k
 	return NOT_BAM;
 }
 
-void RecordOutputMgr::printRecord(const Record *record)
+void RecordOutputMgr::printRecord(Record *record)
 {
 	RecordKeyVector keyList(record);
 	printRecord(keyList);
 }
 
-void RecordOutputMgr::printRecord(const Record *record, const QuickString & value)
+void RecordOutputMgr::printRecord(Record *record, const string & value)
 {	
 	checkForHeader();
 
@@ -158,7 +152,7 @@ void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<int> *
 
 	const ContextClosest *context = static_cast<const ContextClosest *>(_context);
 	bool deleteBlocks = false;
-	const Record *keyRec = keyList.getKey();
+	Record *keyRec = keyList.getKey();
 	RecordKeyVector blockList(keyRec);
 	if (keyRec->getType() == FileRecordTypeChecker::BAM_RECORD_TYPE) {
 		_bamBlockMgr->getBlocks(blockList, deleteBlocks);
@@ -166,7 +160,7 @@ void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<int> *
 	}
 	if (!keyList.empty()) {
 		int distCount = 0;
-		for (RecordKeyVector::const_iterator_type iter = keyList.begin(); iter != keyList.end(); iter = keyList.next()) {
+		for (RecordKeyVector::iterator_type iter = keyList.begin(); iter != keyList.end(); iter = keyList.next()) {
 			const Record *hitRec = *iter;
 			printKey(keyRec, keyRec->getStartPosStr(), keyRec->getEndPosStr());
 			tab();
@@ -177,7 +171,9 @@ void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<int> *
 				int dist = (*dists)[distCount];
 				//if not using sign distance, use absolute value instead.
 				dist = context->signDistance() ? dist : abs(dist);
-				_outBuf.append(dist);
+				ostringstream s;
+				s << dist;
+				_outBuf.append(s.str());
 				distCount++;
 			}
 			newline();
@@ -188,13 +184,14 @@ void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<int> *
 		tab();
 		// need to add a dummy file id if multiple DB files are used
 		if (_context->getNumInputFiles() > 2) {
-			_outBuf.append('.');
+			_outBuf.append(".");
 			tab();
 		}		
 		null(false, true);
 		if (context->reportDistance()) {
 			tab();
-			_outBuf.append(-1);
+
+			_outBuf.append("-1");
 		}
 		newline();
 	}
@@ -249,12 +246,12 @@ void RecordOutputMgr::printRecord(RecordKeyVector &keyList, RecordKeyVector *blo
 					tab();
 					// need to add a dummy file id if multiple DB files are used
 					if (_context->getNumInputFiles() > 2) {
-						_outBuf.append('.');
+						_outBuf.append(".");
 						tab();
 					}
 					null(false, true);
 					tab();
-					_outBuf.append('0');
+					_outBuf.append("0");
 					newline();
 					if (needsFlush()) flush();
 				}
@@ -269,7 +266,7 @@ void RecordOutputMgr::printRecord(RecordKeyVector &keyList, RecordKeyVector *blo
 					tab();
 					// need to add a dummy file id if multiple DB files are used
 					if (_context->getNumInputFiles() > 2) {
-						_outBuf.append('.');
+						_outBuf.append(".");
 						tab();
 					}
 					null(false, true);
@@ -279,7 +276,9 @@ void RecordOutputMgr::printRecord(RecordKeyVector &keyList, RecordKeyVector *blo
 
 					return;
 				}
-			} else {
+			} 
+			else 
+			{
 				if (printBamRecord(keyList, true) == BAM_AS_BAM) {
 					_currBamBlockList = NULL;
 
@@ -287,9 +286,14 @@ void RecordOutputMgr::printRecord(RecordKeyVector &keyList, RecordKeyVector *blo
 					return;
 				}
 				int hitIdx = 0;
-				for (RecordKeyVector::const_iterator_type iter = keyList.begin(); iter != keyList.end(); iter = keyList.next()) {
-					reportOverlapDetail(keyList.getKey(), *iter, hitIdx);
-					hitIdx++;
+				for (RecordKeyVector::iterator_type iter = keyList.begin(); iter != keyList.end(); iter = keyList.next()) 
+				{
+					// a hit can be invalid if there was no enough overlap, etc.
+					//if ((*iter)->isValid())
+					//{
+						reportOverlapDetail(keyList.getKey(), *iter, hitIdx);
+						hitIdx++;
+					//}
 				}
 			}
 		} else { // not printable
@@ -315,9 +319,9 @@ void RecordOutputMgr::checkForHeader() {
 	//If the tool is groupBy, and outheader was set,  but the header is empty, we need to print groupBy's
 	//default header
 	if (_context->getProgram() == ContextBase::GROUP_BY) {
-		const QuickString &header = _context->getFile(0)->getHeader();
+		const string &header = _context->getFile(0)->getHeader();
 		if (header.empty()) {
-			const QuickString &defaultHeader = (static_cast<ContextGroupBy *>(_context))->getDefaultHeader();
+			const string &defaultHeader = (static_cast<ContextGroupBy *>(_context))->getDefaultHeader();
 			_outBuf.append(defaultHeader);
 		} else {
 			_outBuf.append(header);
@@ -326,7 +330,7 @@ void RecordOutputMgr::checkForHeader() {
 		//if the tool is based on intersection, we want the header from the query file.
 
 		int queryIdx = (static_cast<ContextIntersect *>(_context))->getQueryFileIdx();
-		const QuickString &header  = _context->getFile(queryIdx)->getHeader();
+		const string &header  = _context->getFile(queryIdx)->getHeader();
 		_outBuf.append(header);
 	} else {
 		_outBuf.append(_context->getFile(0)->getHeader());
@@ -341,6 +345,7 @@ void RecordOutputMgr::reportOverlapDetail(const Record *keyRecord, const Record
 
 	// overlap interval is defined by min(e1,e2) - max(s1,s2)
 	int maxStart = max(keyRecord->getStartPos(), hitRecord->getStartPos());
+	//cout << keyRecord->getStartPos() << "," << hitRecord->getStartPos();
 	int minEnd = min(keyRecord->getEndPos(), hitRecord->getEndPos());
 
 	// need to undo our conversion of 1-based start coordinates to 0-based
@@ -374,18 +379,22 @@ void RecordOutputMgr::reportOverlapDetail(const Record *keyRecord, const Record
 		hitRecord->print(_outBuf);
 	}
 	else if ((static_cast<ContextIntersect *>(_context))->getWriteOverlap()) {
-		int printOverlapBases = 0;
+		int overlapBases = 0;
 		if (_context->getObeySplits()) {
-			printOverlapBases = _context->getSplitBlockInfo()->getOverlapBases(hitIdx);
+			overlapBases = _context->getSplitBlockInfo()->getOverlapBases(hitIdx);
 		} else {
 			// if one of the records was zerolength, the number of
 			// overlapping bases needs to be corrected 
-			if (keyRecord->isZeroLength() || hitRecord->isZeroLength	())
+			if (keyRecord->isZeroLength() || hitRecord->isZeroLength())
 			{
 				maxStart++;
 				minEnd--;
 			}
-			printOverlapBases = minEnd - maxStart;
+			overlapBases = minEnd - maxStart;
+			// add one to overlapBases since we decremented minStart
+			// for 1-based records.
+			if (!keyRecord->isZeroBased())
+				overlapBases++;
 		}
 		const_cast<Record *>(keyRecord)->undoZeroLength();
 		printKey(keyRecord);
@@ -394,7 +403,7 @@ void RecordOutputMgr::reportOverlapDetail(const Record *keyRecord, const Record
 		const_cast<Record *>(hitRecord)->undoZeroLength();
 		hitRecord->print(_outBuf);
 		tab();
-		int2str(printOverlapBases, _outBuf, true);
+		int2str(overlapBases, _outBuf, true);
 	}
 	newline();
     if (needsFlush()) flush();
@@ -428,14 +437,16 @@ void RecordOutputMgr::reportOverlapSummary(RecordKeyVector &keyList)
 }
 
 void RecordOutputMgr::addDbFileId(int fileId) {
+	ostringstream s;
 	if ((static_cast<ContextIntersect *>(_context))->getNumDatabaseFiles()  == 1) return;
 	if (!_context->getUseDBnameTags() && (!_context->getUseDBfileNames())) {
-		_outBuf.append(fileId);
+		s << fileId;
 	} else if (_context->getUseDBnameTags()){
-		_outBuf.append((static_cast<ContextIntersect *>(_context))->getDatabaseNameTag((static_cast<ContextIntersect *>(_context))->getDbIdx(fileId)));
+		s << (static_cast<ContextIntersect *>(_context))->getDatabaseNameTag((static_cast<ContextIntersect *>(_context))->getDbIdx(fileId));
 	} else {
-		_outBuf.append(_context->getInputFileName(fileId));
+		s << _context->getInputFileName(fileId);
 	}
+	_outBuf.append(s.str());
 	tab();
 }
 
@@ -498,11 +509,13 @@ void RecordOutputMgr::null(bool queryType, bool dbType)
 	default:
 		break;
 	}
-	dummyRecord->printNull(_outBuf);
-	delete dummyRecord;
+	if (dummyRecord) {
+		dummyRecord->printNull(_outBuf);
+		delete dummyRecord;
+	}
 }
 
-void RecordOutputMgr::printKey(const Record *key, const QuickString & start, const QuickString & end)
+void RecordOutputMgr::printKey(const Record *key, const string & start, const string & end)
 {
 	if (key->getType() != FileRecordTypeChecker::BAM_RECORD_TYPE) {
 		key->print(_outBuf, start, end);
