@@ -21,7 +21,14 @@ bool sortByChrom(BED const &a, BED const &b) {
 };
 
 bool sortByStart(const BED &a, const BED &b) {
-    if (a.start < b.start) return true;
+    CHRPOS a_corrected = a.start;
+    if(a.zeroLength)
+        a_corrected++;
+    CHRPOS b_corrected = b.start;
+    if(b.zeroLength)
+        b_corrected++;
+    
+    if (a_corrected < b_corrected) return true;
     else return false;
 };
 
@@ -31,7 +38,9 @@ bool sortBySizeAsc(const BED &a, const BED &b) {
     CHRPOS bLen = b.end - b.start;
 
     if (aLen < bLen) return true;
-    else return false;
+    else if (aLen > bLen) return false;
+    // If they're the same size, sort by position (as expected by tests)
+    else return byChromThenStart(a, b);
 };
 
 bool sortBySizeDesc(const BED &a, const BED &b) {
@@ -64,7 +73,10 @@ bool byChromThenStart(BED const &a, BED const &b) {
     return false;
 };
 
-
+bool sortByWeight(const BED &a, const BED &b) {
+    if (a.weight > b.weight) return true;
+    else return false;
+};
 /*******************************************
 Class methods
 *******************************************/
@@ -767,3 +779,35 @@ void BedFile::loadBedFileIntoVector() {
     Close();
 }
 
+void BedFile::assignWeightsBasedOnSize() {
+    // sort by size
+    sort(bedList.begin(), bedList.end(), sortBySizeAsc);
+    // then assign a weight to each interval based on the
+    // proportion of the total interval length of the file
+    size_t totalSize = 0;
+    for (unsigned int i = 0; i < bedList.size(); ++i) 
+    {
+        totalSize += bedList[i].size();
+    }
+    double totalWeight = 0.0;
+    for (unsigned int i = 0; i < bedList.size(); ++i) 
+    {
+        totalWeight += (double) bedList[i].size() / (double) totalSize;
+        bedList[i].weight = totalWeight;
+    }
+}
+
+struct CompareByWeight {
+    bool operator()(double const val, BED const& bed) const 
+    {
+        return bed.weight > val;
+    }
+};
+
+BED * BedFile::sizeWeightedSearch(double val) {
+    // binary search for first interval with weight greater than search val
+    vector<BED>::iterator up = upper_bound(bedList.begin(), bedList.end(), val, CompareByWeight());
+    return &(*up);
+}
+
+
